@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.18.2.2 2000/07/24 09:39:32 fredgo Exp $
+# $Id: Editor.py,v 1.18.2.4 2001/10/24 15:56:31 fredgo Exp $
 
 import string, re
 from gnome.ui import *
@@ -32,7 +32,7 @@ from Pyblio import Fields, Config, Base, Types, Connector, Exceptions, Key
 
 from Pyblio.GnomeUI import FieldsInfo, Utils, Mime
 
-key_re = re.compile ("^[\w:_+-]+$")
+key_re = re.compile ("^[\w:_+-.]+$")
 
 _newcontent = {
     Fields.AuthorGroup : _("Last Name, First Name"),
@@ -464,6 +464,8 @@ class RealEditor (Connector.Publisher):
         self.newfield_area = GtkHBox (spacing = 5)
         self.newfield_area.set_border_width (5)
         self.newfield = GnomeEntry ('newfield')
+        self.newfield.load_history ()
+        
         self.newfield_area.pack_start (self.newfield)
 
         b = GtkButton (_("Create Field"))
