@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtex.h,v 1.3 2000/02/10 09:41:22 fredgo Exp $
+ $Id: bibtex.h,v 1.4.2.1 2001/11/28 18:06:30 fredgo Exp $
 */
 
 #ifndef __bibtex_h__
@@ -281,7 +281,9 @@ extern "C" {
 
     /* recreate structure after modifications */
 
-    BibtexField * bibtex_reverse_field (BibtexField * field);
+    BibtexField * bibtex_reverse_field (BibtexField * field,
+					gboolean use_braces,
+					gboolean do_quote);
 
     /* --------------------------------------------------
        Low level function
